@@ -18,6 +18,7 @@ from roborock.protocols.v1_protocol import (
 from roborock.roborock_message import RoborockMessage
 from roborock.roborock_typing import RoborockCommand
 
+from .cache import Cache
 from .channel import Channel
 from .local_channel import LocalChannel, LocalSession, create_local_session
 from .mqtt_channel import MqttChannel
@@ -46,6 +47,7 @@ class V1Channel(Channel):
         security_data: SecurityData,
         mqtt_channel: MqttChannel,
         local_session: LocalSession,
+        cache: Cache,
     ) -> None:
         """Initialize the V1Channel.
 
@@ -62,7 +64,7 @@ class V1Channel(Channel):
         self._mqtt_unsub: Callable[[], None] | None = None
         self._local_unsub: Callable[[], None] | None = None
         self._callback: Callable[[RoborockMessage], None] | None = None
-        self._networking_info: NetworkInfo | None = None
+        self._cache = cache
 
     @property
     def is_connected(self) -> bool:
@@ -77,7 +79,7 @@ class V1Channel(Channel):
     @property
     def is_mqtt_connected(self) -> bool:
         """Return whether MQTT connection is available."""
-        return self._mqtt_unsub is not None
+        return self._mqtt_unsub is not None and self._mqtt_channel.is_connected
 
     @property
     def rpc_channel(self) -> V1RpcChannel:
@@ -131,19 +133,26 @@ class V1Channel(Channel):
 
         This is a cloud only command used to get the local device's IP address.
         """
+        cache_data = await self._cache.get()
+        if cache_data.network_info and (network_info := cache_data.network_info.get(self._device_uid)):
+            _LOGGER.debug("Using cached network info for device %s", self._device_uid)
+            return network_info
         try:
-            return await self._mqtt_rpc_channel.send_command(
+            network_info = await self._mqtt_rpc_channel.send_command(
                 RoborockCommand.GET_NETWORK_INFO, response_type=NetworkInfo
             )
         except RoborockException as e:
             raise RoborockException(f"Network info failed for device {self._device_uid}") from e
+        _LOGGER.debug("Network info for device %s: %s", self._device_uid, network_info)
+        cache_data.network_info[self._device_uid] = network_info
+        await self._cache.set(cache_data)
+        return network_info
 
     async def _local_connect(self) -> Callable[[], None]:
         """Set up local connection if possible."""
         _LOGGER.debug("Attempting to connect to local channel for device %s", self._device_uid)
-        if self._networking_info is None:
-            self._networking_info = await self._get_networking_info()
-        host = self._networking_info.ip
+        networking_info = await self._get_networking_info()
+        host = networking_info.ip
         _LOGGER.debug("Connecting to local channel at %s", host)
         self._local_channel = self._local_session(host)
         try:
@@ -168,10 +177,14 @@ class V1Channel(Channel):
 
 
 def create_v1_channel(
-    user_data: UserData, mqtt_params: MqttParams, mqtt_session: MqttSession, device: HomeDataDevice
+    user_data: UserData,
+    mqtt_params: MqttParams,
+    mqtt_session: MqttSession,
+    device: HomeDataDevice,
+    cache: Cache,
 ) -> V1Channel:
     """Create a V1Channel for the given device."""
     security_data = create_security_data(user_data.rriot)
     mqtt_channel = MqttChannel(mqtt_session, device.duid, device.local_key, user_data.rriot, mqtt_params)
     local_session = create_local_session(device.local_key)
-    return V1Channel(device.duid, security_data, mqtt_channel, local_session=local_session)
+    return V1Channel(device.duid, security_data, mqtt_channel, local_session=local_session, cache=cache)
